@@ -3,8 +3,7 @@
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef THEMEEDITORPAGE_H
-#define THEMEEDITORPAGE_H
+#pragma once
 
 #include <QWidget>
 
@@ -68,4 +67,3 @@ private:
     bool mChanged = false;
 };
 
-#endif // THEMEEDITORPAGE_H
